import React from 'react';
import { createUseStyles } from 'react-jss';
const useStyles = createUseStyles({
    heading: {
        borderBottom: '1px solid var(--jp-border-color2)',
        margin: 0,
        padding: '24px 16px 8px 16px',
        fontWeight: 'bold',
        textAlign: 'start',
        fontSize: '9pt',
        textTransform: 'uppercase'
    }
});
export const HorizontalHeading = ({ title }) => {
    const classes = useStyles();
    return React.createElement("div", { className: classes.heading }, title);
};
